@@ -20,10 +20,12 @@ Dot and sum
 
 .. autofunction:: sum2diag
 .. autofunction:: ddot
+.. autofunction:: cdot
 
 Properties
 ^^^^^^^^^^
 
+.. autofunction:: check_semidefinite_positiveness
 .. autofunction:: check_definite_positiveness
 .. autofunction:: check_symmetry
 
@@ -49,9 +51,10 @@ Solvers
 from .cho import cho_solve
 from .det import plogdet
 from .diag import sum2diag, trace2
-from .dot import ddot, dotd
+from .dot import ddot, dotd, cdot
 from .lstsq import lstsq
 from .lu import lu_slogdet, lu_solve
+from .property import check_semidefinite_positiveness
 from .property import check_definite_positiveness, check_symmetry
 from .qs import economic_qs, economic_qs_linear
 from .solve import rsolve, solve
@@ -62,5 +65,5 @@ __all__ = [
     'cho_solve', 'sum2diag', 'trace2', 'ddot', 'dotd', 'lu_slogdet',
     'lu_solve', 'check_definite_positiveness', 'check_symmetry', 'economic_qs',
     'economic_qs_linear', 'solve', 'rsolve', 'economic_svd', 'stl', 'lstsq',
-    'plogdet'
+    'plogdet', 'check_semidefinite_positiveness', 'cdot'
 ]
